Files
kumomta/crates
Wez Furlong d30a6718cb tsa: improve publish throughput by 2.3x
On my test system, running `k6 run tsa-torture.js` (included in this
commit) could achieve ~26,000 qps.

With the changes in this commit I see ~60,000 qps.

The gains are realized by introducing batching and transactions in the
publish code path, and allowing sqlite to avoid a synchronous flush.

Turning down the tracing::info! that was logging when rules
were matched made a non-trivial impact on throughput;
35k qps with info!, 60k qps with it at the current debug!, so I've
put it at debug.
2024-11-23 12:36:16 -07:00
..
2024-11-13 13:50:27 -07:00
2024-11-13 13:50:27 -07:00
2024-11-15 13:42:51 -07:00
2024-11-13 13:50:27 -07:00
2024-07-03 14:59:52 -07:00